@@ -8,14 +8,13 @@ import marshmallow as ma
 from marshmallow import ValidationError
 from marshmallow.utils import missing
 
-from webargs.fields import DelimitedList
+from webargs.multidictproxy import MultiDictProxy
 
 logger = logging.getLogger(__name__)
 
 
 __all__ = [
     "ValidationError",
-    "is_multiple",
     "Parser",
     "missing",
     "parse_json",
@@ -57,11 +56,6 @@ def _callable_or_raise(obj: typing.Optional[T]) -> typing.Optional[T]:
     return obj
 
 
-def is_multiple(field: ma.fields.Field) -> bool:
-    """Return whether or not `field` handles repeated/multi-value arguments."""
-    return isinstance(field, ma.fields.List) and not isinstance(field, DelimitedList)
-
-
 def get_mimetype(content_type: str) -> str:
     return content_type.split(";")[0].strip()
 
@@ -132,10 +126,10 @@ class Parser:
     DEFAULT_LOCATION: str = "json"
     #: Default value to use for 'unknown' on schema load
     #  on a per-location basis
-    DEFAULT_UNKNOWN_BY_LOCATION: typing.Dict[str, str] = {
-        "json": ma.RAISE,
-        "form": ma.RAISE,
-        "json_or_form": ma.RAISE,
+    DEFAULT_UNKNOWN_BY_LOCATION: typing.Dict[str, typing.Optional[str]] = {
+        "json": None,
+        "form": None,
+        "json_or_form": None,
         "querystring": ma.EXCLUDE,
         "query": ma.EXCLUDE,
         "headers": ma.EXCLUDE,
@@ -148,6 +142,8 @@ class Parser:
     DEFAULT_VALIDATION_STATUS: int = DEFAULT_VALIDATION_STATUS
     #: Default error message for validation errors
     DEFAULT_VALIDATION_MESSAGE: str = "Invalid value."
+    #: field types which should always be treated as if they set `is_multiple=True`
+    KNOWN_MULTI_FIELDS: typing.List[typing.Type] = [ma.fields.List, ma.fields.Tuple]
 
     #: Maps location => method name
     __location_map__: typing.Dict[str, typing.Union[str, typing.Callable]] = {
@@ -176,6 +172,12 @@ class Parser:
         self.schema_class = schema_class or self.DEFAULT_SCHEMA_CLASS
         self.unknown = unknown
 
+    def _makeproxy(
+        self, multidict, schema: ma.Schema, cls: typing.Type = MultiDictProxy
+    ):
+        """Create a multidict proxy object with options from the current parser"""
+        return cls(multidict, schema, known_multi_fields=tuple(self.KNOWN_MULTI_FIELDS))
+
     def _get_loader(self, location: str) -> typing.Callable:
         """Get the loader function for the given location.
 
@@ -320,7 +322,10 @@ class Parser:
             location_data = self._load_location_data(
                 schema=schema, req=req, location=location
             )
-            data = schema.load(location_data, **load_kwargs)
+            preprocessed_data = self.pre_load(
+                location_data, schema=schema, req=req, location=location
+            )
+            data = schema.load(preprocessed_data, **load_kwargs)
             self._validate_arguments(data, validators)
         except ma.exceptions.ValidationError as error:
             self._on_validation_error(
@@ -521,6 +526,15 @@ class Parser:
         self.error_callback = func
         return func
 
+    def pre_load(
+        self, location_data: Mapping, *, schema: ma.Schema, req: Request, location: str
+    ) -> Mapping:
+        """A method of the parser which can transform data after location
+        loading is done. By default it does nothing, but users can subclass
+        parsers and override this method.
+        """
+        return location_data
+
     def _handle_invalid_json_error(
         self,
         error: typing.Union[json.JSONDecodeError, UnicodeDecodeError],
